@@ -3,6 +3,8 @@ package Net::Curl::Promiser::LoopBase;
 use strict;
 use warnings;
 
+=encoding utf-8
+
 =head1 NAME
 
 Net::Curl::Promiser::LoopBase - Base class for event-loop-based implementations
@@ -49,8 +51,4 @@ sub _SETOPT_FORBIDDEN {
     );
 }
 
-sub _GET_FD_ACTION {
-    return +{ @{ $_[1] } };
-}
-
 1;
